<?php
/*
 * ARI Quiz Results Community Builder plugin
 *
 * @package		ARI Quiz Results Community Builder plugin
 * @version		1.0.0
 * @author		ARI Soft
 * @copyright	Copyright (c) 2009 www.ari-soft.com. All rights reserved
 * @license		GNU/GPL (http://www.gnu.org/copyleft/gpl.html)
 * 
 */

if (!(defined('_VALID_CB') || defined('_JEXEC') || defined('_VALID_MOS'))) die('Direct Access to this location is not allowed.');

class AriQuizResultsTabHelper
{
	static function loadAriFramework()
	{
		static $loaded;

		if (!is_null($loaded)) return $loaded;
		
		global $_CB_framework;
		
		$kernelPath = $_CB_framework->getCfg('absolute_path') . '/administrator/components/com_ariquiz/kernel/class.AriKernel.php';
		if (!@file_exists($kernelPath))
		{
			$loaded = false;
			return $loaded;
		}
		
		require_once $kernelPath;
		
		AriKernel::import('SimpleTemplate.SimpleTemplate');
		AriKernel::import('Web.Controls.Data.MultiPageDataTable');
		AriKernel::import('Web.JSON.JSON');
		
		require_once JPATH_ADMINISTRATOR . '/components/com_ariquiz/models/quizresults.php';
		require_once JPATH_ADMINISTRATOR . '/components/com_ariquiz/tables/quiz.php';
		require_once JPATH_ADMINISTRATOR . '/components/com_ariquiz/tables/userquiz.php';
		
		$loaded = true;
		
		return $loaded;
	}
}

class AriQuizResultsTabAjaxDispatcher
{
	var $_commandVar = 'aqrt';
	
	function dispatch($user)
	{
		$act = cbGetParam($_REQUEST, $this->_commandVar);
		if (empty($act) || !preg_match('/^[A-z]+$/', $act)) return false;

		$method = $this->getMethod($act); 
		if (method_exists($this, $method))
		{
			if (!AriQuizResultsTabHelper::loadAriFramework()) return false;

			$this->$method($user);
		}
		
		return true;
	}
	
	function getMethod($act)
	{
		return 'run_' . $act;
	}
	
	function run_getQuizResults($user)
	{
		AriKernel::import('Data.DataFilter');
		
		$userId = $user->get('id');
		$sortField = JRequest::getString('sortField');
		$sortDirection = JRequest::getString('sortOrder');

		$filter = new AriDataFilter(
			array(
				'startOffset' => 0, 
				'limit' => 10, 
				'sortField' => $sortField, 
				'dir' => $sortDirection,
				'filter' => array(
					'UserId' => $userId
				)
			), 
			true, 
			null
		);

		$resultsModel = AriModel::getInstance('Quizresults', 'AriQuizModel');
		$totalCnt = $resultsModel->getResultCount($filter);
		$filter->fixFilter($totalCnt);

		$results = $this->_extendStats(
			$resultsModel->getResultList($filter)
		);		
		$data = AriMultiPageDataTableControl::createDataInfo($results, $filter, $totalCnt); 

		while (@ob_end_clean());
		
		header('Content-type: text/html; charset=utf-8');
		
		echo json_encode($data);
		exit();
	}
	
	function _extendStats($results)
	{
		if (empty($results)) return $results;

		global $Itemid;
		
		for ($i = 0; $i < count($results); $i++)
		{
			$result =& $results[$i];
            $result->StartDate = AriDateUtility::formatDate($result->StartDate);
            $result->EndDate = AriDateUtility::formatDate($result->EndDate);
            $result->StartDate2 = AriDateUtility::formatDate($result->StartDate2);
            $result->EndDate2 = AriDateUtility::formatDate($result->EndDate2);
			$result->DetailsLink = JRoute::_(
				'index.php?option=com_ariquiz&view=quizcomplete&ticketId=' . $result->TicketId . '&Itemid=' . $Itemid, false, false, false);
		}
		
		return $results;
	}
}

class getAriQuizResultsTab extends cbTabHandler 
{
	function __construct() 
	{
		$this->cbTabHandler();
	}
	
	function getDisplayTab($tab, $user, $ui) 
	{
		global $_CB_framework, $_CB_database, $mainframe;

		if (!AriQuizResultsTabHelper::loadAriFramework())
		{
			return '<b style="color: red;">Quizzes results can\'t be shown. Check, please, that ARI Quiz component is correctly installed and you have version 2.7.1+.</b>';
		}
		
		$lang = JFactory::getLanguage();
		$lang->load('com_ariquiz');

		$ajaxDispatcher = new AriQuizResultsTabAjaxDispatcher();
		$ajaxDispatcher->dispatch($user);

		$params = $this->params;
		$sortField = $params->get('sort', 'EndDate2');
		$sortOrder = $params->get('sortOrder', 'DESC'); 

		$dsUrl = JURI::root(true) . '/index.php?option=com_comprofiler&task=userProfiler&aqrt=getQuizResults&user=' . $user->id . '&sortField=' . $sortField . '&sortOrder=' . $sortOrder;		
		$columns = array(
			new AriDataTableControlColumn(array('key' => '', 'label' => JText::_('COM_ARIQUIZ_LABEL_NUMPOS'), 'formatter' => 'YAHOO.ARISoft.widgets.DataTable.formatters.formatPosition', 'className' => 'dtCenter dtColMin')),
			new AriDataTableControlColumn(array('key' => 'QuizName', 'label' => JText::_('COM_ARIQUIZ_LABEL_QUIZ'), 'sortable' => true)),
			new AriDataTableControlColumn(array('key' => 'StartDate2', 'label' => JText::_('COM_ARIQUIZ_LABEL_STARTDATE'), 'sortable' => true)),
			new AriDataTableControlColumn(array('key' => 'EndDate2', 'label' => JText::_('COM_ARIQUIZ_LABEL_ENDDATE'), 'sortable' => true)),
			new AriDataTableControlColumn(array('key' => 'UserScore', 'label' => '', 'hidden' => true)),
			new AriDataTableControlColumn(array('key' => 'MaxScore', 'label' => '', 'hidden' => true)),
			new AriDataTableControlColumn(array('key' => 'PercentScore', 'label' => JText::_('COM_ARIQUIZ_LABEL_SCORE'), 'sortable' => true, 'formatter' => 'YAHOO.ARISoft.Quiz.formatters.formatResultScore', 'className' => 'dtNoWrap')),
			new AriDataTableControlColumn(array('key' => 'Passed', 'label' => JText::_('COM_ARIQUIZ_LABEL_STATUS'), 'sortable' => true, 'formatter' => 'YAHOO.ARISoft.Quiz.formatters.formatPassed')),
			new AriDataTableControlColumn(array('key' => 'DetailsLink', 'label' => JText::_('COM_ARIQUIZ_LABEL_DETAILS'), 'formatter' => 'YAHOO.ARISoft.Quiz.formatters.formatUserResultDetails'))
		);

		$dataTable = new AriMultiPageDataTableControl(
			'dtAriQuizResults',
			$columns,
			array('dataUrl' => $dsUrl),
			array(
				'firstPageLinkLabel' => null,
				'lastPageLinkLabel' => null,
				'nextPageLinkLabel' => null,
				'previousPageLinkLabel' => null,
				'pageReportTemplate' => null,
				'template' => '<div style="text-align: center;">Display#: {RowsPerPageDropdown} {FirstPageLink} {PreviousPageLink} {PageLinks} {NextPageLink} {LastPageLink} {CurrentPageReport}</div>'
			));
		
		@ob_start();
		$dataTable->render();
		$dtDefinition = ob_get_contents();
		@ob_clean();
		@ob_end_flush();

	    $beforeText = $params->get('beforeText', '');
		$afterText = $params->get('afterText', '');
		
		$liveSite = $_CB_framework->getCfg('live_site');
		$jsAdminPath = $liveSite . '/components/com_ariquiz/assets/js/';
		$cssPath = $liveSite . '/components/com_ariquiz/assets/css/';

		$content = sprintf(
			'<link rel="stylesheet" type="text/css" href="%1$syui.combo.css" />
			<link rel="stylesheet" type="text/css" href="%1$sstyles.css" />
			<script type="text/javascript" src="%2$syui.combo.js"></script>
			<script charset="utf-8" src="%2$sari.all.js?v=%3$s" type="text/javascript"></script>
			<script charset="utf-8" src="%2$sari.quiz.js?v=%3$s" type="text/javascript"></script>
			<script charset="utf-8" src="%2$sari.pageController.js?v=%3$s" type="text/javascript"></script>
			<script charset="utf-8" src="%7$s/index.php?option=com_ariquiz&view=jsmessages&task=getMessages" type="text/javascript"></script> 
			<script type="text/javascript">
				YAHOO.ARISoft.page.baseUrl = "%7$s/";
				YAHOO.ARISoft.page.adminBaseUrl = "%7$s/administrator/";
				YAHOO.ARISoft.page.option = "com_ariquiz";
			</script>
			%5$s
			<div class="yui-skin-sam">%4$s</div>
			%6$s',
			$cssPath,
			$jsAdminPath,
			time(),
			$dtDefinition,
			$beforeText,
			$afterText,
			$liveSite
		);

		return $content;
	}
}